@@ -8,13 +8,13 @@ from .utils import get_clones
 
 class TransformerEncoderLayer(nn.Module):
 
-    def __init__(self, d_model, nhead, dim_feedforward=2048, dropout=0.1):
+    def __init__(self, hidden_size, nhead, dim_feedforward=2048, dropout=0.1):
         super().__init__()
-        self.selfAttn = TransformerMultiHeadAttention(d_model, dim_feedforward, nhead, dropout)
-        self.feedForward = TransformerMLP(d_model, dim_feedforward, dropout)
+        self.selfAttn = TransformerMultiHeadAttention(hidden_size, dim_feedforward, nhead, dropout)
+        self.feedForward = TransformerMLP(hidden_size, dim_feedforward, dropout)
 
-        self.norm_1 = col_nn.LayerNorm(d_model)
-        self.norm_2 = col_nn.LayerNorm(d_model)
+        self.norm_1 = col_nn.LayerNorm(hidden_size)
+        self.norm_2 = col_nn.LayerNorm(hidden_size)
         self.dropout_1 = col_nn.Dropout(dropout)
         self.dropout_2 = col_nn.Dropout(dropout)
 
