@@ -9,7 +9,7 @@ from ..init_rules import init_rules
 class ViTMLP(nn.Module):
 
     def __init__(self,
-                 dim: int,
+                 hidden_size: int,
                  mlp_ratio: int,
                  activation: Callable,
                  dropout: float,
@@ -17,24 +17,27 @@ class ViTMLP(nn.Module):
                  bias: bool = True,
                  init_method: str = 'torch'):
         super().__init__()
-        self.dense_1 = col_nn.Linear(dim,
-                                     mlp_ratio * dim,
+        self.dense_1 = col_nn.Linear(hidden_size,
+                                     mlp_ratio * hidden_size,
                                      dtype=dtype,
                                      bias=bias,
                                      **init_rules[init_method]['transformer'])
         self.activation = activation
         self.dropout_1 = col_nn.Dropout(dropout)
-        self.dense_2 = col_nn.Linear(mlp_ratio * dim,
-                                     dim,
+        self.dense_2 = col_nn.Linear(mlp_ratio * hidden_size,
+                                     hidden_size,
                                      dtype=dtype,
                                      bias=bias,
                                      **init_rules[init_method]['transformer'])
         self.dropout_2 = col_nn.Dropout(dropout)
 
     def forward(self, x):
+        # the size of x before dense_1 is (BATCH_SIZE, SEQ_LEN, HIDDEN_SIZE)
+        # the size of x after dense_1 is (BATCH_SIZE, SEQ_LEN, HIDDEN_SIZE*mlp_ratio)
         x = self.dense_1(x)
         x = self.activation(x)
         x = self.dropout_1(x)
+        # the size of x after dense_2 is (BATCH_SIZE, SEQ_LEN, HIDDEN_SIZE)
         x = self.dense_2(x)
         x = self.dropout_2(x)
         return x
