@@ -8,7 +8,7 @@ class MLPForMoe(nn.Module):
     """
 
     def __init__(self,
-                 d_model: int,
+                 hidden_size: int,
                  d_ff: int,
                  activation=None,
                  drop_rate: float = 0,
@@ -16,9 +16,9 @@ class MLPForMoe(nn.Module):
                  dropout1=None,
                  dropout2=None):
         super().__init__()
-        dense1 = nn.Linear(d_model, d_ff, bias, device=get_current_device())
+        dense1 = nn.Linear(hidden_size, d_ff, bias, device=get_current_device())
         act = nn.GELU() if activation is None else activation
-        dense2 = nn.Linear(d_ff, d_model, bias, device=get_current_device())
+        dense2 = nn.Linear(d_ff, hidden_size, bias, device=get_current_device())
         drop1 = nn.Dropout(drop_rate) if dropout1 is None else dropout1
         drop2 = nn.Dropout(drop_rate) if dropout2 is None else dropout2
 
